==> cl-sql_2.11.6.orig.tar.gz: cl-sql-2.11.6/db-odbc/odbc-loader.lisp <==
;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          odbc-loader.sql
;;;; Purpose:       ODBC library loader using UFFI
;;;; Programmers:   Kevin M. Rosenberg
;;;; Date Started:  April 2004
;;;;
;;;; $Id: odbc-loader.lisp 9450 2004-05-23 10:51:02Z kevin $
;;;;
;;;; This file, part of CLSQL, is Copyright (c) 2004 by Kevin M. Rosenberg
;;;;
;;;; CLSQL users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;; *************************************************************************

(in-package #:odbc)

(defparameter *odbc-library-path* 
  (uffi:find-foreign-library
   '("odbc32" "libodbc" "libiodbc")
   `(,(make-pathname :directory (pathname-directory *load-truename*))
     #+64bit "/usr/lib64/"
      "/usr/lib/"
      "/sw/lib/"
      "/usr/local/lib/"
      "/home/kevin/debian/src/clsql/db-odbc/"
      "/windows/system32/"
      "/odbc/lib/opt/")
   :drive-letters '("C")))
  
(defvar *odbc-supporting-libraries* '("c")
  "Used only by CMU. List of library flags needed to be passed to ld to
load the Odbc client library succesfully.  If this differs at your site,
set to the right path before compiling or loading the system.")

(defvar *odbc-library-loaded* nil
  "T if foreign library was able to be loaded successfully")

(defmethod clsql-sys:database-type-library-loaded ((database-type (eql :odbc)))
  *odbc-library-loaded*)
				      
(defmethod clsql-sys:database-type-load-foreign ((database-type (eql :odbc)))
  (uffi:load-foreign-library *odbc-library-path*
			     :module "odbc") 
  (setq *odbc-library-loaded* t))

(clsql-sys:database-type-load-foreign :odbc)

==> cl-sql_3.8.4.orig.tar.gz: cl-sql-3.8.4/db-odbc/odbc-loader.lisp <==
;;;; -*- Mode: LISP; Syntax: ANSI-Common-Lisp; Base: 10 -*-
;;;; *************************************************************************
;;;; FILE IDENTIFICATION
;;;;
;;;; Name:          odbc-loader.sql
;;;; Purpose:       ODBC library loader using UFFI
;;;; Programmers:   Kevin M. Rosenberg
;;;; Date Started:  April 2004
;;;;
;;;; $Id: odbc-loader.lisp 10575 2005-06-08 19:25:26Z kevin $
;;;;
;;;; This file, part of CLSQL, is Copyright (c) 2004 by Kevin M. Rosenberg
;;;;
;;;; CLSQL users are granted the rights to distribute and use this software
;;;; as governed by the terms of the Lisp Lesser GNU Public License
;;;; (http://opensource.franz.com/preamble.html), also known as the LLGPL.
;;;; *************************************************************************

(in-package #:odbc)

(defparameter *odbc-library-filenames* 
  '("odbc32" "libodbc" "libiodbc"))
  
(defvar *odbc-supporting-libraries* '("c")
  "Used only by CMU. List of library flags needed to be passed to ld to
load the Odbc client library succesfully.  If this differs at your site,
set to the right path before compiling or loading the system.")

(defvar *odbc-library-loaded* nil
  "T if foreign library was able to be loaded successfully")

(defmethod clsql-sys:database-type-library-loaded ((database-type (eql :odbc)))
  *odbc-library-loaded*)
				      
(defmethod clsql-sys:database-type-load-foreign ((database-type (eql :odbc)))
  (clsql-uffi:find-and-load-foreign-library *odbc-library-filenames*
                                            :module "odbc")
  (setq *odbc-library-loaded* t))

(clsql-sys:database-type-load-foreign :odbc)
